package Weed::ArrayField;
use strict;
use warnings;

our $VERSION = '0.0011';

use Weed;

our $DESCRIPTION = 'X3DArrayField : X3DField { }';

1;
__END__
